# 📜 blueflow

📜 [`blueflow`](./blueflow/) for workflow management on aws batch and more.

```bash
pip install blueflow
```

|   |   |
| --- | --- |
| 📜[`workflow`](https://github.com/kamangir/notebooks-and-scripts/tree/main/blueflow/workflow) [![image](https://kamangir-public.s3.ca-central-1.amazonaws.com/hourglass/workflow.gif?raw=true)](https://github.com/kamangir/notebooks-and-scripts/tree/main/blueflow/workflow) an abstraction to run mixed-type (cpu/gpu/...) [DAG](https://networkx.org/documentation/stable/reference/classes/digraph.html)s of commands on [aws batch](https://aws.amazon.com/batch/), and a few other compute resources. | 📜[`scripts`](https://github.com/kamangir/notebooks-and-scripts/tree/main/scripts) [![image](https://github.com/kamangir/assets/blob/main/nbs/3x4.jpg?raw=true)](https://github.com/kamangir/notebooks-and-scripts/tree/main/scripts) legacy mechanisms replaced with `@docker eval - <command>` and `@batch eval - <command>`. |

---


[![pylint](https://github.com/kamangir/notebooks-and-scripts/actions/workflows/pylint.yml/badge.svg)](https://github.com/kamangir/notebooks-and-scripts/actions/workflows/pylint.yml) [![pytest](https://github.com/kamangir/notebooks-and-scripts/actions/workflows/pytest.yml/badge.svg)](https://github.com/kamangir/notebooks-and-scripts/actions/workflows/pytest.yml) [![bashtest](https://github.com/kamangir/notebooks-and-scripts/actions/workflows/bashtest.yml/badge.svg)](https://github.com/kamangir/notebooks-and-scripts/actions/workflows/bashtest.yml) [![PyPI version](https://img.shields.io/pypi/v/blueflow.svg)](https://pypi.org/project/blueflow/) [![PyPI - Downloads](https://img.shields.io/pypi/dd/blueflow)](https://pypistats.org/packages/blueflow)

built by 🌀 [`blue_options-4.126.1`](https://github.com/kamangir/awesome-bash-cli), based on 📜 [`blueflow-4.769.1`](https://github.com/kamangir/notebooks-and-scripts).

---

used to be [`notebooks-and-scripts`](https://pypi.org/project/notebooks-and-scripts/).
